colour.colorimetry.cmfs Module — Colour 0.3.0 documentation

# colour.colorimetry.cmfs Module

## Colour Matching Functions

Defines colour matching functions classes for the dataset from `colour.colorimetry.dataset.cmfs`:

- `LMS_ConeFundamentals`: Implements support for the Stockman & Sharpe LMS cone fundamentals colour matching functions.
- `RGB_ColourMatchingFunctions`: Implements support for the CIE RGB colour matching functions.
- `XYZ_ColourMatchingFunctions`: Implements support for the CIE Standard Observers XYZ colour matching functions.

See also

Colour Matching Functions IPython Notebook colour.colorimetry.dataset.cmfs, colour.colorimetry.spectrum.TriSpectralPowerDistribution

class `colour.colorimetry.cmfs.` `LMS_ConeFundamentals`(name, data)

  Bases: `colour.colorimetry.spectrum.TriSpectralPowerDistribution`

  Implements support for the Stockman & Sharpe LMS cone fundamentals colour matching functions.

  Parameters: | name (unicode) – LMS colour matching functions name. data (dict) – LMS colour matching functions.

  `l_bar`
  `m_bar`
  `s_bar`
  `l_bar`

    Property for self.x attribute.

    Returns: | self.x
    Return type: | SpectralPowerDistribution

    Warning

    `LMS_ConeFundamentals.l_bar` is read only.

  `m_bar`

    Property for self.y attribute.

    Returns: | self.y
    Return type: | SpectralPowerDistribution

    Warning

    `LMS_ConeFundamentals.m_bar` is read only.

  `s_bar`

    Property for self.z attribute.

    Returns: | self.z
    Return type: | SpectralPowerDistribution

    Warning

    `LMS_ConeFundamentals.s_bar` is read only.

class `colour.colorimetry.cmfs.` `RGB_ColourMatchingFunctions`(name, data)

  Bases: `colour.colorimetry.spectrum.TriSpectralPowerDistribution`

  Implements support for the CIE RGB colour matching functions.

  Parameters: | name (unicode) – CIE RGB colour matching functions name. data (dict) – CIE RGB colour matching functions.

  `r_bar`
  `g_bar`
  `b_bar`
  `b_bar`

    Property for self.z attribute.

    Returns: | self.z
    Return type: | SpectralPowerDistribution

    Warning

    `RGB_ColourMatchingFunctions.b_bar` is read only.

  `g_bar`

    Property for self.y attribute.

    Returns: | self.y
    Return type: | SpectralPowerDistribution

    Warning

    `RGB_ColourMatchingFunctions.g_bar` is read only.

  `r_bar`

    Property for self.x attribute.

    Returns: | self.x
    Return type: | SpectralPowerDistribution

    Warning

    `RGB_ColourMatchingFunctions.r_bar` is read only.

class `colour.colorimetry.cmfs.` `XYZ_ColourMatchingFunctions`(name, data)

  Bases: `colour.colorimetry.spectrum.TriSpectralPowerDistribution`

  Implements support for the CIE Standard Observers XYZ colour matching functions.

  Parameters: | name (unicode) – CIE Standard Observer XYZ colour matching functions name. data (dict) – CIE Standard Observer XYZ colour matching functions.

  `x_bar`
  `y_bar`
  `z_bar`
  `x_bar`

    Property for self.x attribute.

    Returns: | self.x
    Return type: | SpectralPowerDistribution

    Warning

    `XYZ_ColourMatchingFunctions.x_bar` is read only.

  `y_bar`

    Property for self.y attribute.

    Returns: | self.y
    Return type: | SpectralPowerDistribution

    Warning

    `XYZ_ColourMatchingFunctions.y_bar` is read only.

  `z_bar`

    Property for self.z attribute.

    Returns: | self.z
    Return type: | SpectralPowerDistribution

    Warning

    `XYZ_ColourMatchingFunctions.z_bar` is read only.